pub struct TokenContract { /* private fields */ }Expand description
Typed wrapper for the token contract.
Implementations
Sourceimpl TokenContract
impl TokenContract
Sourcepub fn new(
client: AElfClient,
wallet: Wallet,
address: impl Into<String>,
) -> TokenContract
pub fn new( client: AElfClient, wallet: Wallet, address: impl Into<String>, ) -> TokenContract
Creates a typed token contract wrapper.
Sourcepub async fn get_balance(
&self,
input: &GetBalanceInput,
) -> Result<GetBalanceOutput, ContractError>
pub async fn get_balance( &self, input: &GetBalanceInput, ) -> Result<GetBalanceOutput, ContractError>
Returns the token balance for a given owner and symbol.
Sourcepub async fn get_token_info(
&self,
input: &GetTokenInfoInput,
) -> Result<TokenInfo, ContractError>
pub async fn get_token_info( &self, input: &GetTokenInfoInput, ) -> Result<TokenInfo, ContractError>
Returns token metadata for a specific symbol.
Sourcepub async fn get_native_token_info(&self) -> Result<TokenInfo, ContractError>
pub async fn get_native_token_info(&self) -> Result<TokenInfo, ContractError>
Returns metadata for the chain’s native token.
Sourcepub async fn get_primary_token_symbol(&self) -> Result<String, ContractError>
pub async fn get_primary_token_symbol(&self) -> Result<String, ContractError>
Returns the primary token symbol used by the chain.
Sourcepub async fn transfer(
&self,
input: &TransferInput,
) -> Result<SendTransactionOutput, ContractError>
pub async fn transfer( &self, input: &TransferInput, ) -> Result<SendTransactionOutput, ContractError>
Transfers tokens to another address.
Sourcepub async fn cross_chain_transfer(
&self,
input: &CrossChainTransferInput,
) -> Result<SendTransactionOutput, ContractError>
pub async fn cross_chain_transfer( &self, input: &CrossChainTransferInput, ) -> Result<SendTransactionOutput, ContractError>
Sends tokens to another chain through the token contract.